@@ -1,6 +1,6 @@
 import os
 
-ELK_URL = os.getenv('ELK_URL', 'https://elastic.sysnet.cz')
+ELK_URL = os.getenv('ELK_URL', 'https://elastic.sysnet.cz:443')
 ELK_USERNAME = os.getenv('ELK_USERNAME', None)
 ELK_PASSWORD = os.getenv('ELK_PASSWORD', None)
 ELK_CERTS_DIR = os.getenv('ELK_CERTS_DIR', 'certs')
