@@ -17,21 +17,37 @@ def create_es_client(
             return None
         if ca_certs not in ['', None]:
             if verify_certs:
+                if user not in [None, '']:
+                    out = Elasticsearch(
+                        hosts=str(url),
+                        ca_certs=str(ca_certs),
+                        basic_auth=(user, password),
+                        verify_certs=True)
+                else:
+                    out = Elasticsearch(
+                        hosts=str(url),
+                        ca_certs=str(ca_certs),
+                        verify_certs=True)
+            else:
+                if user not in [None, '']:
+                    out = Elasticsearch(
+                        hosts=str(url),
+                        basic_auth=(user, password),
+                        verify_certs=False)
+                else:
+                    out = Elasticsearch(
+                        hosts=str(url),
+                        verify_certs=False)
+        else:
+            if user not in [None, '']:
                 out = Elasticsearch(
                     hosts=str(url),
-                    ca_certs=str(ca_certs),
-                    http_auth=(user, password),
-                    verify_certs=True)
+                    basic_auth=(user, password),
+                    verify_certs=False)
             else:
                 out = Elasticsearch(
                     hosts=str(url),
-                    http_auth=(user, password),
                     verify_certs=False)
-        else:
-            out = Elasticsearch(
-                hosts=str(url),
-                http_auth=(user, password),
-                verify_certs=False)
     # except elasticsearch.ElasticsearchException:
     except ApiError as e:
         raise ShoppingError(e)
